<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 11/14/2003 *
 * ===================                          Last change: 11/25/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : mailid.php                                       *
 * -------------------------------------------------------------------- *
 * Short description : Confirmation file for emails                     *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Bestaetigung von Mails                           *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Load security stuff here
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['startTime'] = microtime(true);

// Tell everyone we are in this module
$GLOBALS['module'] = 'mailid';
$GLOBALS['output_mode'] = -1;
$errorCode = '';

// Load the required file(s)
require('inc/config-global.php');

// Set content type and HTTP status
setContentType('text/html');
setHttpStatus('404 NOT FOUND');

// Is the extension active?
redirectOnUninstalledExtension('mailid');

// Init
$userId  = '0';
$bonusId = '0';
$mailId  = '0';

// Secure all data
if (isGetRequestElementSet('userid'))  $userId  = bigintval(getRequestElement('userid'));
if (isGetRequestElementSet('mailid'))  $mailId  = bigintval(getRequestElement('mailid'));
if (isGetRequestElementSet('bonusid')) $bonusId = bigintval(getRequestElement('bonusid'));

// 01           1        12            2    2            21    1                      2210
if ((isValidUserId($userId)) && (($mailId > 0) || ($bonusId > 0)) && (!ifFatalErrorsDetected())) {
	// Init result
	$result_link = false;

	// Maybe he wants to confirm an email?
	if ($mailId > 0) {
		// Member mail
		$result_link = SQL_QUERY_ESC("SELECT `link_type` FROM `{?_MYSQL_PREFIX?}_user_links` WHERE `stats_id`=%s AND `userid`=%s LIMIT 1",
			array($mailId, $userId), __FILE__, __LINE__);
		$type = 'mailid';
		$urlId = $mailId;
	} elseif ($bonusId > 0) {
		// Bonus mail
		$result_link = SQL_QUERY_ESC("SELECT `link_type` FROM `{?_MYSQL_PREFIX?}_user_links` WHERE `bonus_id`=%s AND `userid`=%s LIMIT 1",
			array($bonusId, $userId), __FILE__, __LINE__);
		$type = 'bonusid';
		$urlId = $bonusId;
	} else {
		// Problem: No id entered
		redirectToUrl('modules.php?module=index');
	}

	if (SQL_NUMROWS($result_link) == 1) {
		// Load the entry
		list($ltype) = SQL_FETCHROW($result_link);

		// @TODO Rewrite this to a filter
		switch ($ltype) {
			case 'NORMAL':
				// Is the stats id valid?
				$result = SQL_QUERY_ESC("SELECT `pool_id`,`url`,`subject` FROM `{?_MYSQL_PREFIX?}_user_stats` WHERE `id`=%s LIMIT 1",
					array($mailId), __FILE__, __LINE__);
				break;

			case 'BONUS':
				// Is the bonus extension active?
				redirectOnUninstalledExtension('bonus');

				// Bonus-Mails
				$result = SQL_QUERY_ESC("SELECT `id`,`url`,`subject` FROM `{?_MYSQL_PREFIX?}_bonus` WHERE `id`=%s LIMIT 1",
					array($bonusId), __FILE__, __LINE__);
				break;

			default: // Invalid mail type
				debug_report_bug(__FILE__, __LINE__, 'Invalid mail type ' . $ltype . ' detected.');
				break;
		} // END - switch

		if (SQL_NUMROWS($result) == 1) {
			// Load data
			list($pool, $url, $title) = SQL_FETCHROW($result);

			// Free result
			SQL_FREERESULT($result);

			// Set it
			setExtraTitle($title);

			// Is the user's id unlocked?
			if (fetchUserData($userId)) {
				// Status must be CONFIRMED
				if (getUserData('status') == 'CONFIRMED') {
					// Update last activity if not admin
					if ((!isAdmin()) || (isDebugModeEnabled())) {
						// Is not admin, so update last activity
						updateLastActivity($userId);
					} // END - if

					// User has confirmed his account so we can procede...
					// @TODO Rewrite this to a filter
					switch ($ltype) {
						case 'NORMAL':
							$result = SQL_QUERY_ESC("SELECT `payment_id` FROM `{?_MYSQL_PREFIX?}_user_stats` WHERE `pool_id`=%s LIMIT 1",
								array(bigintval($pool)), __FILE__, __LINE__);
							if (SQL_NUMROWS($result) == 1) {
								list($pay) = SQL_FETCHROW($result);
								$time      = getPaymentPoints($pay, 'time');
								$payment   = getPaymentPoints($pay, 'payment');
								$isValid   = true;
							} // END - if

							// Free memory
							SQL_FREERESULT($result);
							break;

						case 'BONUS':
							$result = SQL_QUERY_ESC("SELECT `points`,`time` FROM `{?_MYSQL_PREFIX?}_bonus` WHERE `id`=%s LIMIT 1",
								array($bonusId), __FILE__, __LINE__);
							if (SQL_NUMROWS($result) == 1) {
								list($points, $time) = SQL_FETCHROW($result);
								$payment = '0.00000';
								$isValid = true;
							} // END - if

							// Free memory
							SQL_FREERESULT($result);
							break;

						default: // Invalid mail type
							debug_report_bug(__FILE__, __LINE__, 'Invalid mail type ' . $ltype . ' detected.');
							break;
					}

					// Add header
					loadIncludeOnce('inc/header.php');

					// Was that mail a valid one?
					if ($isValid === true) {
						// If time is zero seconds we have a sponsor mail. 1 Second shall be set to avoid problems
						if (($time == '0') && ($payment > 0)) { 
							$url = getUrl();
							$time = 1; 
						} // END - if

						if (($time > 0) && (($payment > 0) || ($points > 0))) {
							// Set HTTP status to okay
							setHttpStatus('200 OK');

							// Export data into constants for the template
							$content = array(
								'userid'  => $userId,
								'type'    => $type,
								'data'    => $urlId,
								'url'     => $url
							);

							// Load template
							loadTemplate('mailid_frames', false, $content);
						} else {
							$errorCode = getCode('DATA_INVALID');
						}
					} else {
						$errorCode = getCode('POSSIBLE_INVALID');
					}
				} else {
					$errorCode = getCode('ACCOUNT_' . getUserData('status'));
				}
			} else {
				$errorCode = getCode('USER_404');
			}
		} else {
			$errorCode = getCode('STATS_404');
		}
	} else {
		$errorCode = getCode('ALREADY_CONFIRMED');
	}

	// Free result
	SQL_FREERESULT($result_link);
} else {
	// Nothing entered
	$errorCode = getCode('ERROR_MAILID');
}

// Error code is set?
handleMailIdErrorCode($errorCode);

// Include footer
loadIncludeOnce('inc/footer.php');

// [EOF]
?>
